@@ -1,7 +1,7 @@
 package Elive::Connection;
 use warnings; use strict;
 
-our $VERSION = '1.34';
+our $VERSION = '1.35';
 
 use Carp;
 use File::Spec::Unix;
@@ -30,7 +30,7 @@ Most of the time, you'll be dealing with specific class instances; See L<Elive::
 
 =cut
 
-__PACKAGE__->mk_accessors( qw{url user pass _soap debug type timeout} );
+__PACKAGE__->mk_accessors( qw{_url user pass _soap debug type timeout} );
 
 =head1 METHODS
 
@@ -97,9 +97,6 @@ sub _connect {
 	    }
 	}
     }
-    else {
-	warn "no credentials in url: $url" if $debug;
-    }
 
     my $uri_path = $uri_obj->path;
 
@@ -314,6 +311,12 @@ Returns a restful url for the connection.
 
 =cut
 
+sub url {
+    my $self = shift;
+    $self->_url(@_) if @_;
+    return $self->_url;
+}
+
 sub DESTROY {
     shift->disconnect;
     return;
